

set -ex



test -L $PREFIX/lib/libcudart.so.12
test -L $PREFIX/lib/libcudart.so.12.6.68
test -L $PREFIX/targets/sbsa-linux/lib/libcudart.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libcudart.so.12.6.68
exit 0
